Windows build fixes.
[libdcp.git] / src / dcp.h
index 9bd5f3ea66b8d312d4316c5a5ba58c45bbccb545..bc829fe96d1e69be5a837fc2ccdf8060b9edb95e 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
 #define LIBDCP_DCP_H
 
 #include <string>
-#include <list>
+#include <vector>
 #include <boost/shared_ptr.hpp>
 #include <sigc++/sigc++.h>
 #include "types.h"
 
+namespace xmlpp {
+       class Node;
+}
+
 /** @brief Namespace for everything in libdcp */
 namespace libdcp
 {
@@ -43,28 +47,16 @@ class Asset;
 class DCP
 {
 public:
-       enum ContentType
-       {
-               FEATURE,
-               SHORT,
-               TRAILER,
-               TEST,
-               TRANSITIONAL,
-               RATING,
-               TEASER,
-               POLICY,
-               PUBLIC_SERVICE_ANNOUNCEMENT,
-               ADVERTISEMENT
-       };
-
        /** Construct a DCP.
         *  @param directory Directory to write files to.
         *  @param name Name.
-        *  @param content_type Content type.
+        *  @param content_kind Content kind.
         *  @param fps Frames per second.
         *  @param length Length in frames.
         */
-       DCP (std::string directory, std::string name, ContentType content_type, int fps, int length);
+       DCP (std::string directory, std::string name, ContentKind content_kind, int fps, int length);
+
+       DCP (std::string directory);
 
        /** Add a sound asset.
         *  @param files Pathnames of WAV files to use in the order Left, Right,
@@ -98,6 +90,24 @@ public:
         */
        void write_xml () const;
 
+       std::string name () const {
+               return _name;
+       }
+
+       ContentKind content_kind () const {
+               return _content_kind;
+       }
+
+       int frames_per_second () const {
+               return _fps;
+       }
+
+       int length () const {
+               return _length;
+       }
+
+       std::list<std::string> equals (DCP const & other, EqualityFlags flags) const;
+
        /** Emitted with a parameter between 0 and 1 to indicate progress
         *  for long jobs.
         */
@@ -130,17 +140,12 @@ private:
         */
        void write_assetmap (std::string cpl_uuid, int cpl_length, std::string pkl_uuid, int pkl_length) const;
 
-       /** @param type A content type.
-        *  @return A string representation suitable for use in a CPL.
-        */
-       static std::string content_type_string (ContentType type);
-
        /** the directory that we are writing to */
        std::string _directory;
        /** the name of the DCP */
        std::string _name;
-       /** the content type of the DCP */
-       ContentType _content_type;
+       /** the content kind of the DCP */
+       ContentKind _content_kind;
        /** frames per second */
        int _fps;
        /** length in frames */